from .client import *
from .error import *

WOWS_NA = "https://api.worldofwarships.com"
WOWS_ASIA = "https://api.worldofwarships.asia"
WOWS_EU = "https://api.worldofwarships.eu"
WOWS_RU = "https://api.worldofwarships.ru"
